# OsSom

View audio data in real time.

This package is still under its first development iteration and is mostly developed under Linux, although it is intended to run on any plataform.

I'll be glad to help on any issue, just ticket it on [GitHub](https://github.com/chum4k3r/ossom.git).

I'll be even more glad if you are able to contribute and help me fight those stinky bugs that comes after any new code.


### Installation

The most up to date code available:
    
    `pip install git+https://github.com/chum4k3r/ossom.git`


The most up to date released code available:

    `pip install https://github.com/Chum4k3r/ossom/archive/v0.1.0-alpha.zip`
